#
# spec file for package metis
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define somajor 5
%define libname lib%{name}%{somajor}

Name:           metis
Version:        5.1.0
Release:        13.1
Summary:        Serial Graph Partitioning and Fill-reducing Matrix Ordering
License:        Apache-2.0
Group:          Productivity/Scientific/Math
URL:            http://glaros.dtc.umn.edu/gkhome/metis/metis/overview
Source0:        %{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE metis-cmake.patch
Patch1:         metis-cmake.patch
# PATCH-FIX-OPENSUSE metis-programs-no-compilation-time.patch -- Fix W: file-contains-date-and-time
Patch2:         metis-programs-no-compilation-time.patch
Patch3:         metis-makefile-c-directives.patch
# PATCH-FIX-OPENSUSE: require at least cmake 3.5 in order to allow building against cmake 4
Patch4:         metis-min-cmake-3.5.patch
BuildRequires:  cmake >= 3.5
BuildRequires:  gcc
BuildRequires:  gcc-c++

Recommends:     %{name}-doc = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
METIS is a family of programs for partitioning unstructured graphs and hypergraph
and computing fill-reducing orderings of sparse matrices. The underlying algorithms
used by METIS are based on a multilevel paradigm that, at the time, had been
shown to produce quality results and scale to large problems.

%package     -n %{libname}
Summary:        Serial Graph Partitioning and Fill-reducing Matrix Ordering library
Group:          System/Libraries
Obsoletes:      %libname < %{version}

%description -n %{libname}
METIS library provides to partitioning unstructured graphs and hypergraph
and computing fill-reducing orderings of sparse matrices. The underlying algorithms
used by METIS are based on a multilevel paradigm that, at the time, had been
shown to produce quality results and scale to large problems.

%package        devel
Summary:        Metis development files
Group:          Development/Libraries/C and C++
Requires:       %libname = %{version}

%description    devel
METIS library provides to partitioning unstructured graphs and hypergraph
and computing fill-reducing orderings of sparse matrices. The underlying algorithms
used by METIS are based on a multilevel paradigm that, at the time, had been
shown to produce quality results and scale to large problems.

This package provides development files.

%package        doc
Summary:        Metis documentation
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
METIS is a family of programs for partitioning unstructured graphs and hypergraph
and computing fill-reducing orderings of sparse matrices. The underlying algorithms
used by METIS are based on a multilevel paradigm that, at the time, had been
shown to produce quality results and scale to large problems.

%package        examples
Summary:        Metis examples
Group:          Documentation/Other
BuildArch:      noarch

%description    examples
METIS library provides to partitioning unstructured graphs and hypergraph
and computing fill-reducing orderings of sparse matrices. This package provides
graph files you can use to test Metis.

%prep
%autosetup -p1 -n %{name}-%{version}

# set width (32 or 64 bits) of the elementary data type, see Install.txt
sed -i 's|#define IDXTYPEWIDTH 32|#define IDXTYPEWIDTH %{__isa_bits}|' include/metis.h

%build

make config shared=1 prefix=%{_prefix} cflags="%{optflags} -fopenmp -pthread -fpie -pie" ldflags="-pie"
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}

%check
pushd graphs
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH %{buildroot}%{_bindir}/ndmetis mdual.graph
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH %{buildroot}%{_bindir}/mpmetis metis.mesh 2
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH %{buildroot}%{_bindir}/gpmetis test.mgraph 4
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH %{buildroot}%{_bindir}/gpmetis copter2.graph 4
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH %{buildroot}%{_bindir}/graphchk 4elt.graph
popd
cd graphs # cleanup after tests:
rm test.mgraph.part.4 metis.mesh.epart.2 metis.mesh.npart.2 copter2.graph.part.4 mdual.graph.iperm

%post -n %libname -p /sbin/ldconfig

%postun -n %libname -p /sbin/ldconfig

%files
%doc Changelog
%license LICENSE.txt
%{_bindir}/*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{somajor}*

%files devel
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so

%files doc
%doc manual/manual.pdf

%files examples
%doc graphs

%changelog
* Wed Jul 16 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Add metis-min-cmake-3.5.patch: declare cmake 3.5 as minimal
  required version in order to allow building using cmake 4, which
  sets 3.5 as arbitrary lower limit. CMake 3.5 was release in 2016,
  so we can get away with simply not caring for older things.
* Mon Mar 24 2025 Nicolas Morey <nicolas.morey@suse.com>
- Disable and remove support for gnu-hpc build flavours (bsc#1239982)
- Remove upstream URL for Source0 as all links are dead.
* Wed Apr  3 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Cleanup after tests
* Fri Feb 23 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Thu Jul 23 2020 Egbert Eich <eich@suse.com>
- Add build support for gcc10 to HPC build (bsc#1174439).
* Wed Feb 26 2020 Egbert Eich <eich@suse.com>
- Add support for gcc8/9 building (jsc#SLE-8604).
* Fri Mar 15 2019 Egbert Eich <eich@suse.com>
- Build HPC master package for 'examples'.
* Tue Feb 12 2019 Antoine Ginies <aginies@suse.com>
- add a examples subpackage which include graphs* file to test Metis
* Mon Feb 11 2019 Egbert Eich <eich@suse.com>
- Set default module version correctly when installing
  master package, unset when deinstalling the default library
  package.
- Fix %%%%post and %%%%postun scripts for HPC.
- Fix dependencies for HPC.
- Fix HPC modulefile:
  * Aibraries are always there when module file is installed.
  * Set PKG_CONFIG_PATH.
- Fix package group names.
* Mon Jan 14 2019 eich@suse.com
- Remove dependency to a non-existing module package for HPC.
* Thu Nov 22 2018 Jan Engelhardt <jengelh@inai.de>
- Edit description to put time-sensitive wording into context.
* Fri Oct 26 2018 eich@suse.com
- General spec file clean up.
- Touch-up to the HPC build.
* Thu Nov 30 2017 jjolly@suse.com
- Implemented suse-hpc packaging
- Added metis-makefile-c-directives.patch
  - Provides cflags option to help provide metis native build process
* Fri Jun 20 2014 dmitry_r@opensuse.org
- Update to version 5.1.0, changes since version 4.0
  * strtoidx() addition for portable input file parsing
  * Fixed some bad memory allocation calls
  * Incorporated GKlib into METIS, which replaced many of its
    internal functions.
  * A nearly complete re-write of Metis' code-based that changed
    expanded the functionality of the command-line programs and
    API routines
  * Multi-constraint partitioning can be used in conjunction with
    minimization of the total communication volume.
  * All graph and mesh partitioning routines take as input the
    target sizes of the partitions, which among others, allow them
    to compute partitioning solutions that are well-suited for
    parallel architectures with heterogeneous computing capabilities.
  * When multi-constraint partitioning is used, the target sizes of
    the partitions are specified on a per partition-constraint pair.
  * The multilevel k-way partitioning algorithms can compute a
    partitioning solution in which each partition is contiguous.
  * All partitioning and ordering routines can compute multiple
    different solutions and select the best as the final solution.
  * The mesh partitioning and mesh-to-graph conversion routines can
    operate on mixed element meshes.
  * The command-line programs provide full access to the entire
    set of capabilities provided by Metis' API.
  * Re-written the memory management subsystem to reduce overall
    memory requirements.
  * Added back Fortran support in the form of alternate API names
    (see libmetis/frename.h).
  * Changed the license to Apache Version 2
- Move metis shared library to separate package
- Enable build tests
- Use proper build parameters
  * metis-cmake.patch
- Delete compilation time from metis programs to avoid unnecessary
  package republishing
  * metis-programs-no-compilation-time.patch
* Fri Aug 17 2012 scorot@free.fr
- Buildreqs libtool for 12.2 an higher
- spec file reformating
* Sat Mar 17 2012 scorot@free.fr
- remove %%%%debug_package macro which broke build on 11.3
* Sun Nov  8 2009 andrea@opensuse.org
- new package
